@@ -1,5 +1,6 @@
 use std::collections::HashMap;
 
+use headers::{Header, HeaderMapExt};
 use http::{header, header::HeaderName, Extensions, HeaderMap, HeaderValue, Method};
 use serde::Serialize;
 use serde_json::Value;
@@ -93,6 +94,13 @@ where
         self
     }
 
+    /// Inserts a typed header to this request.
+    #[must_use]
+    pub fn typed_header<T: Header>(mut self, header: T) -> Self {
+        self.headers.typed_insert(header);
+        self
+    }
+
     /// Sets the content type for this request.
     #[must_use]
     pub fn content_type(self, content_type: impl AsRef<str>) -> Self {
